'use strict';

const Controller = require('../core/base_controller');

function toInt(str) {
  if (typeof str === 'number') return str;
  if (!str) return str;
  return parseInt(str, 10) || 0;
}

class ProjectController extends Controller {
  async index() {
    const { ctx } = this;
    const { Op } = this.app.Sequelize;
    const user = await ctx.service.user.getcurrentuser();
    // 查询条件
    const query = user?.org_id
      ? [
        {
          project_user_id: user?.id,
        },
        {
          org_id: user?.org_id,
        },
      ]
      : [
        {
          project_user_id: user?.id,
        },
      ];
    let result = await ctx.model.Project.findAll({
      where: {
        [Op.or]: query,
      },
    });

    let alluser = await ctx.model.User.findAll({
      attributes: {
        exclude: [ 'password' ],
      },
    });
    let allsteps = await ctx.model.Step.findAll();
    let allitems = await ctx.model.Item.findAll();
    alluser = alluser.map(it => it?.dataValues);
    result = result.map(it => it?.dataValues);
    allsteps = allsteps.map(it => it?.dataValues);
    allitems = allitems.map(it => it?.dataValues);

    // 小组成员可见过滤
    const datafliter = result
      ?.filter(it => {
        return (
          it.user_list.indexOf(user?.id) !== -1 ||
          it?.project_user_id === user?.id
        );
      })
      ?.map(it => {
        it.user_info_list = alluser?.filter(
          item =>
            it.user_list.indexOf(item.id) !== -1 ||
            it?.project_user_id === item.id
        );
        let allinitem = [];
        const steps = allsteps
          ?.filter(item => item.project_id === it.id)
          .map(item => {
            // 过滤当前项目下的所有任务；
            const thisitems = allitems.filter(
              itemz => itemz.project_id === it.id && itemz.step_id === item.id
            );
            allinitem.push(thisitems);
            return {
              ...item,
              items: thisitems,
            };
          });
        allinitem = allinitem.flat();
        console.log(allinitem);

        const stastic = [
          {
            status: '0',
            statusName: '未开始',
            num: allinitem.filter(it => it.status === '0'),
          },
          {
            status: '1',
            statusName: '进行中',
            num: allinitem.filter(it => it.status === '1'),
          },
          {
            status: '2',
            statusName: '已完成',
            num: allinitem.filter(it => it.status === '2'),
          },
        ];
        const total = allinitem.length;
        return { ...it, steps, stastic, total };
      });
    this.success(datafliter);
  }

  async show() {
    const ctx = this.ctx;
    const { status } = ctx.query;
    const result = await ctx.model.Project.findByPk(toInt(ctx.params.id));
    const user_info_list = await ctx.model.User.findAll({
      where: {
        id: result?.dataValues?.user_list,
      },
      attributes: {
        exclude: [ 'password' ],
      },
    });
    let steps = await ctx.service.step.getbyproject_id(ctx.params.id);
    const items = await ctx.service.item.getbyproject_id(ctx.params.id , status);

    steps = steps.map(it => {
      return {
        ...it?.dataValues,
        items: items ? items.filter(item => item.step_id === it?.id) : [],
      };
    });

    this.success({
      ...result?.dataValues,
      user_info_list,
      steps,
    });
  }

  async create() {
    const ctx = this.ctx;
    if (!ctx.request.body.project_name) {
      this.fail('请完善必填项！');
      return;
    }
    const user = await ctx.service.user.getcurrentuser();
    const user_info_list = await ctx.model.User.findAll({
      where: {
        id: ctx.request.body.user_list,
      },
      attributes: {
        exclude: [ 'password' ],
      },
    });
    const project = await ctx.model.Project.create({
      ...ctx.request.body,
      project_user_id: user?.id,
      org_id: user?.org_id,
      user_info_list,
    });
    if (ctx.request.body.steps?.length > 0) {
      await ctx.service.step.muticreate(ctx.request.body.steps, project?.id);
    }

    this.success(project);
  }

  async update() {
    const ctx = this.ctx;
    const id = toInt(ctx.params.id);
    const project = await ctx.model.Project.findByPk(id);
    if (!project) {
      ctx.status = 404;
      ctx.body = {
        code: 1,
        success: false,
        msg: '库里没有该条数据',
      };
      return;
    }
    await project.update(ctx.request.body);
    this.success(project);
  }

  async destroy() {
    const ctx = this.ctx;
    const id = toInt(ctx.params.id);
    const project = await ctx.model.Project.findByPk(id);
    if (!project) {
      ctx.status = 404;
      ctx.body = {
        code: 1,
        success: false,
        msg: '库里没有该条数据',
      };
      return;
    }

    await project.destroy();
    this.success({
      data: '已删除',
    });
  }
}

module.exports = ProjectController;
