'use strict';

const Controller = require('../core/base_controller');

function toInt(str) {
  if (typeof str === 'number') return str;
  if (!str) return str;
  return parseInt(str, 10) || 0;
}

class StepController extends Controller {
  async index() {
    const ctx = this.ctx;
    const query = {
      limit: toInt(ctx.query.limit),
      offset: toInt(ctx.query.offset),
    };
    const result = await ctx.model.Step.findAll(query);
    this.success(result);
  }

  async show() {
    const ctx = this.ctx;
    const result = await ctx.model.Step.findByPk(toInt(ctx.params.id));
    this.success(result);
  }

  async create() {
    const ctx = this.ctx;
    console.log(ctx.request.body);
    if (!ctx.request.body.name) {
      this.fail('请完善必填项！');
      return;
    }
    const step = await ctx.model.Step.create(ctx.request.body);
    this.success(step);
  }

  async update() {
    const ctx = this.ctx;
    const id = toInt(ctx.params.id);
    const step = await ctx.model.Step.findByPk(id);
    if (!step) {
      ctx.status = 404;
      ctx.body = {
        code: 1,
        success: false,
        msg: '库里没有该条数据',
      };
      return;
    }
    await step.update(ctx.request.body);
    this.success(step);
  }

  async destroy() {
    const ctx = this.ctx;
    const id = toInt(ctx.params.id);
    const step = await ctx.model.Step.findByPk(id);
    if (!step) {
      ctx.status = 404;
      ctx.body = {
        code: 1,
        success: false,
        msg: '库里没有该条数据',
      };
      return;
    }

    await step.destroy();
    this.success({
      data: '已删除',
    });
  }
}

module.exports = StepController;
