/* eslint-disable no-unused-vars */
'use strict';

module.exports = app => {
  const { STRING, INTEGER, ENUM, DATE } = app.Sequelize;

  const Org = app.model.define(
    'org',
    {
      id: { type: INTEGER, primaryKey: true, autoIncrement: true },
      org_name: {
        type: STRING(255),
        allowNull: true,
        comment: '组织名',
        unique: true,
      },
      org_users: {
        type: STRING(512),
        allowNull: true,
        comment: '组织成员',
        unique: true,
      },
      org_join_key: {
        type: STRING(255),
        allowNull: true,
        comment: '组织邀请码',
        unique: true,
      },
      org_projects: {
        type: STRING(512),
        allowNull: true,
        comment: '组织项目',
        unique: true,
      },
      otherkey: {
        type: STRING(512),
        allowNull: true,
        comment: '拓展字段1',
        unique: true,
      },
      otherkeys: {
        type: STRING(255),
        allowNull: true,
        comment: '拓展字段2',
        unique: true,
      },
      otherkeyc: {
        type: STRING(255),
        allowNull: true,
        comment: '拓展字段3',
        unique: true,
      },
      created_at: DATE,
      updated_at: DATE,
    },
    {
      timestamps: true,
      createdAt: 'created_at',
      updatedAt: 'updated_at',
    }
  );
  return Org;
};

//     freezeTableName: true,  使用自定义表名
//     // 实例对应的表名
//     tableName: 'user',
//     // 如果需要sequelize帮你维护createdAt,updatedAt和deletedAt必须先启用timestamps功能
//     // 将createdAt对应到数据库的created_at字段
//     createdAt: 'created_at',
//     // 将updatedAt对应到数据库的updated_at字段
//     updatedAt: 'updated_at',
//     //And deletedAt to be called destroyTime (remember to enable paranoid for this to work)
//     deletedAt: false, //'deleted_at',
//     //删除数据时不删除数据，而是更新deleteAt字段 如果需要设置为true，则上面的deleteAt字段不能为false，也就是说必须启用
//     paranoid: false
